@@ -5,6 +5,7 @@ import importlib.metadata
 import itertools
 import json
 import logging
+import re
 import typing as t
 from enum import Enum
 from pathlib import Path
@@ -857,7 +858,7 @@ class Graph:
         reader = csv.reader(obj, delimiter="\t")
         g = cls(name)
 
-        inodes = {}
+        atom_nodes = {}
         mc = atom_class(utils.parse("", nlp))
         g.add_node(mc)
         g._major_claim = mc
@@ -869,9 +870,9 @@ class Graph:
                 if metadata[0] == "MajorClaim":
                     mc.text = utils.parse(mc.plain_text + ". " + row[2], nlp)
                 else:
-                    inode = atom_class(utils.parse(row[2], nlp))
-                    g.add_node(inode)
-                    inodes[row[0]] = inode
+                    atom = atom_class(utils.parse(row[2], nlp))
+                    g.add_node(atom)
+                    atom_nodes[row[0]] = atom
 
             elif row[0].startswith("A") or row[0].startswith("R"):
                 if row[0].startswith("A"):
@@ -880,22 +881,113 @@ class Graph:
                         if metadata[2] == "Against"
                         else SchemeType.SUPPORT
                     )
-                    source_inode = inodes[metadata[1]]
-                    target_inode = mc
+                    source = atom_nodes[metadata[1]]
+                    target = mc
                 else:
                     scheme_type = (
                         SchemeType.ATTACK
                         if metadata[0] == "attacks"
                         else SchemeType.SUPPORT
                     )
-                    source_inode = inodes[metadata[1].split(":")[1]]
-                    target_inode = inodes[metadata[2].split(":")[1]]
+                    source = atom_nodes[metadata[1].split(":")[1]]
+                    target = atom_nodes[metadata[2].split(":")[1]]
 
-                snode = scheme_class(scheme_type)
-                g.add_node(snode)
+                scheme = scheme_class(scheme_type)
+                g.add_node(scheme)
 
-                g.add_edge(edge_class(source_inode, snode))
-                g.add_edge(edge_class(snode, target_inode))
+                g.add_edge(edge_class(source, scheme))
+                g.add_edge(edge_class(scheme, target))
+
+        return g
+
+    @classmethod
+    def from_kialo(
+        cls,
+        obj: t.IO,
+        name: t.Optional[str] = None,
+        atom_class: t.Type[AtomNode] = AtomNode,
+        scheme_class: t.Type[SchemeNode] = SchemeNode,
+        edge_class: t.Type[Edge] = Edge,
+        nlp: t.Optional[t.Callable[[str], t.Any]] = None,
+    ) -> Graph:
+        if name_match := re.search(r"Discussion Title: (.*)", obj.readline()):
+            name = name_match.group(1)
+
+        # After the title, an empty line should follow
+        assert obj.readline().strip() == ""
+
+        g = cls(name)
+
+        # Example: 1.1. Pro: Gold is better than silver.
+        # Pattern: {ID}.{ID}. {STANCE (OPTIONAL)}: {TEXT}
+        pattern = re.compile(r"^(1\.(?:\d+\.)+) (?:(Con|Pro): )?(.*)")
+        current_line = obj.readline()
+        next_line = obj.readline()
+
+        mc_match = re.search(r"^((?:\d+\.)+) (.*)", current_line)
+
+        if not mc_match:
+            raise ValueError("The major claim is not present in the third line!")
+
+        mc_id = mc_match.group(1)
+        mc_text = mc_match.group(2)
+
+        # See in the following while loop for explanation of this block
+        while next_line and not pattern.search(next_line):
+            mc_text = f"{mc_text}\n{next_line.strip()}"
+            next_line = obj.readline()
+
+        mc = _kialo_atom_node(mc_id, mc_text, nlp, atom_class)
+        g.add_node(mc)
+        g.major_claim = mc
+
+        current_line = next_line
+        next_line = obj.readline()
+
+        while current_line:
+            if current_match := pattern.search(current_line):
+                source_id = current_match.group(1)
+                source_id_parts = source_id[:-1].split(".")
+                level = len(source_id_parts)
+                stance = current_match.group(2)
+                text = current_match.group(3)
+
+                # The text of a node is allowed to span multiple lines.
+                # Thus, we need to look ahead to concatenate the complete text.
+                # As long as the pattern is not found in the next line,
+                # we assume that the text belongs to the previous statement.
+                while next_line and not pattern.search(next_line):
+                    text = f"{text}\n{next_line.strip()}"
+                    next_line = obj.readline()
+
+                assert source_id
+                assert text
+
+                if id_ref_match := re.search(r"^-> See ((?:\d+\.)+)", text):
+                    id_ref = id_ref_match.group(1)
+                    source = g.atom_nodes[id_ref]
+                else:
+                    source = _kialo_atom_node(source_id, text, nlp, atom_class)
+                    g.add_node(source)
+
+                if stance:
+                    stance = stance.lower()
+                    scheme = scheme_class(
+                        SchemeType.ATTACK if stance == "con" else SchemeType.SUPPORT,
+                        id=f"{source_id}scheme",
+                    )
+                else:
+                    scheme = scheme_class(SchemeType.REPHRASE, id=f"{source_id}scheme")
+
+                target_id = ".".join(source_id_parts[:-1] + [""])
+                target = g.atom_nodes[target_id]
+
+                g.add_node(scheme)
+                g.add_edge(edge_class(source, scheme, id=f"{source.id}->{scheme.id}"))
+                g.add_edge(edge_class(scheme, target, id=f"{scheme.id}->{target.id}"))
+
+                current_line = next_line
+                next_line = obj.readline()
 
         return g
 
@@ -911,10 +1003,14 @@ class Graph:
         nlp: t.Optional[t.Callable[[str], t.Any]] = None,
     ) -> Graph:
         """Generate Graph structure from IO argument graph file(Link?)."""
-        if suffix == ".ann":
-            return cls.from_brat(obj, name, atom_class, scheme_class, edge_class, nlp)
+        args = (obj, name, atom_class, scheme_class, edge_class, nlp)
 
-        return cls.from_json(obj, name, atom_class, scheme_class, edge_class, nlp)
+        if suffix == ".ann":
+            return cls.from_brat(*args)
+        if suffix == ".txt":
+            return cls.from_kialo(*args)
+
+        return cls.from_json(*args)
 
     def to_io(
         self,
@@ -1124,6 +1220,28 @@ def _node_distance(
     return None
 
 
+def _kialo_atom_node(
+    id: str,
+    text: str,
+    nlp: t.Optional[t.Callable[[str], t.Any]],
+    atom_class: t.Type[AtomNode],
+) -> AtomNode:
+    # Remove backslashes before parentheses/brackets
+    text = re.sub(r"\\([\[\]\(\)])", r"\1", text)
+
+    # Remove markdown links
+    text = re.sub(
+        r"\[(.*?)\]\(.*?\)",
+        r"\1",
+        text,
+    )
+
+    # Apply user-provided nlp function
+    text = utils.parse(text, nlp)
+
+    return atom_class(text, id=id)
+
+
 def render(
     g: gv.dot.Dot,
     path: Path,
